package com.goldenwater.gx.service;

import java.util.List;
import com.goldenwater.gx.domain.GxExchangeBiz;

/**
 * 数据交换业务域Service接口
 */
public interface IGxExchangeBizService
{
    public GxExchangeBiz selectGxExchangeBizById(Long id);

    public GxExchangeBiz selectByBizCode(String bizCode);

    public List<GxExchangeBiz> selectGxExchangeBizList(GxExchangeBiz gxExchangeBiz);

    public int insertGxExchangeBiz(GxExchangeBiz gxExchangeBiz);

    public int updateGxExchangeBiz(GxExchangeBiz gxExchangeBiz);

    public int deleteGxExchangeBizByIds(Long[] ids);

    public int deleteGxExchangeBizById(Long id);

    public Integer selectMaxOrderNum();
 }
